@@ -1,15 +1,4 @@
-# Author: Wilson Snyder <wsnyder@wsnyder.org>
-######################################################################
-#
-# Copyright 2002-2008 by Wilson Snyder.  This program is free software;
-# you can redistribute it and/or modify it under the terms of either the GNU
-# General Public License or the Perl Artistic License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
+# See copyright, etc in below POD section.
 ######################################################################
 
 package SVN::S4;
@@ -21,6 +10,7 @@ use Carp;
 use Data::Dumper;
 use SVN::Client;
 # Our stuff
+use SVN::S4::CatOrMods;
 use SVN::S4::FixProp;
 use SVN::S4::Getopt;
 use SVN::S4::Info;
@@ -36,7 +26,7 @@ use strict;
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.031';
+our $VERSION = '1.032';
 
 # SVN::Client methods
 #       $ctx->add($path, $recursive, $pool);
@@ -615,9 +605,9 @@ Create a new SVN::S4 object.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2008 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
-Lesser General Public License or the Perl Artistic License.
+Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
 =head1 AUTHORS
 
