@@ -1,19 +1,7 @@
-# Author: Wilson Snyder <wsnyder@wsnyder.org>
-######################################################################
-#
-# Copyright 2002-2008 by Wilson Snyder.  This program is free software;
-# you can redistribute it and/or modify it under the terms of either the GNU
-# General Public License or the Perl Artistic License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
+# See copyright, etc in below POD section.
 ######################################################################
 
 package SVN::S4::Getopt;
-require 5.006_001;
 
 use strict;
 use vars qw($AUTOLOAD $Debug);
@@ -25,7 +13,7 @@ use Data::Dumper;
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.031';
+our $VERSION = '1.032';
 
 our %_Aliases =
     (
@@ -454,6 +442,9 @@ our %_Args =
 	       .' [PATH...]')},
   #####
   # Commands added in S4
+  'cat-or-mods' => {
+      s4_addition => 1,
+      args => (' [PATH...]')},
   'fixprop'	=> {
       s4_addition => 1,
       args => (' [-q|--quiet]'
@@ -818,9 +809,9 @@ Return the option list, with the specified matching argument removed.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2008 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
-Lesser General Public License or the Perl Artistic License.
+Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
 =head1 AUTHORS
 
